==> haskell-http3-0.0.5-46-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-http3.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 http3
version:              0.0.5
visibility:           public
id:                   http3-0.0.5-9o2Bs3eHu0ub4jeyLde3g
key:                  http3-0.0.5-9o2Bs3eHu0ub4jeyLde3g
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
homepage:             https://github.com/kazu-yamamoto/http3
synopsis:             HTTP/3 library
description:          HTTP/3 library including frames, QPACK, client and server.
category:             Network
abi:                  37ebb03443e1c04b15f6c80f43cce28d
exposed:              True
exposed-modules:
    Network.HQ.Client Network.HQ.Server Network.HTTP3.Client
    Network.HTTP3.Internal Network.HTTP3.Server Network.QPACK
    Network.QPACK.Internal

hidden-modules:
    Imports Network.HTTP3.Config Network.HTTP3.Context
    Network.HTTP3.Control Network.HTTP3.Error Network.HTTP3.Frame
    Network.HTTP3.Recv Network.HTTP3.Send Network.HTTP3.Settings
    Network.HTTP3.Stream Network.QPACK.Error Network.QPACK.HeaderBlock
    Network.QPACK.HeaderBlock.Decode Network.QPACK.HeaderBlock.Encode
    Network.QPACK.HeaderBlock.Prefix Network.QPACK.Instruction
    Network.QPACK.Table Network.QPACK.Table.Dynamic
    Network.QPACK.Table.RevIndex Network.QPACK.Table.Static
    Network.QPACK.Token Network.QPACK.Types

import-dirs:          /usr/lib/ghc-9.4.8/site-local/http3-0.0.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/http3-0.0.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/http3-0.0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http3
hs-libraries:         HShttp3-0.0.5-9o2Bs3eHu0ub4jeyLde3g
depends:
    array-0.5.4.0 base-4.17.2.1 bytestring-0.11.5.3
    case-insensitive-1.2.1.0-B227KtiOix4GTDgvxk3FBB containers-0.6.7
    http-types-0.12.4-Hsb6Y5xUgLKEUlBrgYk3WM
    http2-4.2.2-5C6u1LLLIA4AsKFrp9GdEC
    network-3.1.4.0-7GxbLibXQB6BN49yptQL65
    network-byte-order-0.1.7-D2CHdiOOdOK1rEVBtge3lM
    quic-0.1.20-LKmXifZ9XV33afRfxrySsx
    sockaddr-0.0.1-DWIU0G3TYvG4VNSd9Azkpi stm-2.5.1.0
    time-manager-0.0.1-FjQ4pRgNfgI8rAhyKaVwMR
    unliftio-0.2.25.1-JFZIPKypuxSaOakmu5k8d

haddock-interfaces:   /usr/share/doc/haskell-http3/html/http3.haddock
haddock-html:         /usr/share/doc/haskell-http3/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http3-0.0.5-47-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-http3.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 http3
version:              0.0.5
visibility:           public
id:                   http3-0.0.5-C8X8KnU9W9FLOLIuq9vH6l
key:                  http3-0.0.5-C8X8KnU9W9FLOLIuq9vH6l
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
homepage:             https://github.com/kazu-yamamoto/http3
synopsis:             HTTP/3 library
description:          HTTP/3 library including frames, QPACK, client and server.
category:             Network
abi:                  b0f8246c77b34f0efe1bda5a2b62e549
exposed:              True
exposed-modules:
    Network.HQ.Client Network.HQ.Server Network.HTTP3.Client
    Network.HTTP3.Internal Network.HTTP3.Server Network.QPACK
    Network.QPACK.Internal

hidden-modules:
    Imports Network.HTTP3.Config Network.HTTP3.Context
    Network.HTTP3.Control Network.HTTP3.Error Network.HTTP3.Frame
    Network.HTTP3.Recv Network.HTTP3.Send Network.HTTP3.Settings
    Network.HTTP3.Stream Network.QPACK.Error Network.QPACK.HeaderBlock
    Network.QPACK.HeaderBlock.Decode Network.QPACK.HeaderBlock.Encode
    Network.QPACK.HeaderBlock.Prefix Network.QPACK.Instruction
    Network.QPACK.Table Network.QPACK.Table.Dynamic
    Network.QPACK.Table.RevIndex Network.QPACK.Table.Static
    Network.QPACK.Token Network.QPACK.Types

import-dirs:          /usr/lib/ghc-9.4.8/site-local/http3-0.0.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/http3-0.0.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/http3-0.0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http3
hs-libraries:         HShttp3-0.0.5-C8X8KnU9W9FLOLIuq9vH6l
depends:
    array-0.5.4.0 base-4.17.2.1 bytestring-0.11.5.3
    case-insensitive-1.2.1.0-3FuXchFPXBfLVJKu7fam1O containers-0.6.7
    http-types-0.12.4-9GhteoJuOlZ3ATAYoIbhkU
    http2-4.2.2-2nuBeAJzHjV9QO0ejvJOrK
    network-3.1.4.0-KAEk2uZxmO9GA8hoXz0jL7
    network-byte-order-0.1.7-D2CHdiOOdOK1rEVBtge3lM
    quic-0.1.20-KD24NaIqUpr7sledUTNA3h
    sockaddr-0.0.1-CyubXm274KQCtdWouAFHB8 stm-2.5.1.0
    time-manager-0.0.1-HuUSf68vpunFYMOfSJ39yk
    unliftio-0.2.25.1-FyGtu4mqD7wCBxP02zQmU8

haddock-interfaces:   /usr/share/doc/haskell-http3/html/http3.haddock
haddock-html:         /usr/share/doc/haskell-http3/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
